@@ -22,8 +22,6 @@ use vars qw(@ISA); @ISA = @CMD_ISA;
 use vars @CMD_VARS;  # Value inherited from parent
 
 our $NAME = set_name();
-=pod
-
 =head2 Synopsis:
 
 =cut
@@ -41,7 +39,7 @@ be passed back to the OS. If no exit code is given, 0 is used.
 
 =head2 Examples:
 
- quit                 # quit prompting if we are interactive
+ quit                 # quit; prompt if we are interactive
  quit unconditionally # quit without prompting
  quit!                # same as above
  quit 0               # same as "quit"
