@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2011 Rocky Bernstein <rocky@cpan.org>
+# Copyright (C) 2011, 2014 Rocky Bernstein <rocky@cpan.org>
 use warnings; no warnings 'redefine'; no warnings 'once';
 use rlib '../../../../..';
 
@@ -14,13 +14,29 @@ use vars @Devel::Trepan::CmdProcessor::Command::Subcmd::SUBCMD_VARS;
 
 ## FIXME: do automatically.
 our $CMD = "set confirm";
+=pod
+
+=head2 Synopsis:
+
+=cut
+
 our $HELP   = <<"HELP";
-${CMD} on|off
+=pod
+
+B<set confirm> [B<on>|B<off>]
 
 Set whether to confirm potentially dangerous operations.
 
-Note some commands like 'quit' and 'kill' have a ! suffix which turns
-the confirmation off in that specific instance.
+Note that some commands like
+L<C<quit>|Devel::Trepan::CmdProcessor::Command::Quit> and
+L<C<kill>|Devel::Trepan::CmdProcessor::Command::Kill> have a C<!>
+suffix which turns the confirmation off in that specific instance.
+
+=head2 See also:
+
+L<C<show confirm>|Devel::Trepan::CmdProcessor::Command::Show::Confirm>
+
+=cut
 HELP
 our $SHORT_HELP = "Set whether to confirm potentially dangerous operations.";
 our $MIN_ABBREV = length('con');
@@ -30,7 +46,7 @@ unless (caller) {
   # require_relative '../../mock'
 
   # # FIXME: DRY the below code
-  # my $cmd = 
+  # my $cmd =
   #   Devel::Trepan::MockDebugger::sub_setup(__PACKAGE__, 0);
   # $cmd->run(@$cmd->prefix + ('off'));
   # $cmd->run(@$cmd->prefix + ('ofn'));
