@@ -17,6 +17,25 @@ use vars @Devel::Trepan::CmdProcessor::Command::Subsubcmd::SUBCMD_VARS;
 
 our $IN_LIST      = 1;
 our $MIN_ABBREV   = length('lis');
+=pod
+
+=head2 Synopsis:
+
+=cut
+
+our $HELP   = <<"HELP";
+=pod
+
+B<show max list>
+
+Show the number of source file lines to list
+
+=head2 See also:
+
+L<C<set max list>|Devel::Trepan::CmdProcessor::Set::Max::List>
+
+=cut
+HELP
 our $SHORT_HELP   = 'Show the number of source file lines to list';
 
 unless (caller) {
@@ -25,7 +44,7 @@ unless (caller) {
   # name = File.basename(__FILE__, '.rb')
 
   # dbgr, show_cmd = MockDebugger::showup('show')
-  # max_cmd       = Trepan::SubSubcommand::ShowMax.new(dbgr.core.processor, 
+  # max_cmd       = Trepan::SubSubcommand::ShowMax.new(dbgr.core.processor,
   #                                                     show_cmd)
   # cmd_ary       = Trepan::SubSubcommand::ShowMaxList::PREFIX
   # cmd_name      = cmd_ary.join(' ')
