@@ -1,7 +1,9 @@
 # -*- coding: utf-8 -*-
-use strict;
+use strict; use warnings;
 use Exporter;
-use warnings;
+
+use vars qw(@EXPORT @ISA); @ISA = ('Exporter'); 
+@EXPORT = qw(create_frame);
 
 use rlib '../../..';
 use Devel::Trepan::CmdProcessor;
@@ -15,6 +17,18 @@ sub setup() {
     $proc;
 }
 
+sub create_frame() {
+    my ($pkg, $file, $line, $fn) = caller(0);
+    return [
+	{
+	    file      => $file,
+	    fn        => $fn,
+	    line      => $line,
+	    pkg       => $pkg,
+	}];
+}
+
+
 if (__FILE__ eq $0) {
     my $proc=Devel::Trepan::CmdProcessor::Mock::setup;
     print $proc, "\n";
